## What you can, should, and cannot do

**You CANNOT:**
- Make any changes to documents or files outside of the task file and the test/source files you are reviewing.
- Modify the board directly — the orchestrator and agent tools manage board state.
- Re-implement or refactor anything you find. Report it and let the coder fix it.
